==> dev-plugin-android-0.0.31-sources.jar: com/zoyi/channel/plugin/android/activity/chat/viewholder/ActionMessageHolder.java <==
package com.zoyi.channel.plugin.android.activity.chat.viewholder;

import android.view.View;
import android.widget.FrameLayout;
import android.widget.TextView;
import com.zoyi.channel.plugin.android.ChannelStore;
import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.chat.listener.OnActionMessageClickListener;
import com.zoyi.channel.plugin.android.activity.chat.model.ActionMessageItem;
import com.zoyi.channel.plugin.android.util.ResUtils;

/**
 * Created by mika on 2017. 2. 1..
 */
public class ActionMessageHolder extends ManagerMessageHolder {
  private TextView simpleText;

  private ActionMessageItem item;

  public ActionMessageHolder(
      final View itemView,
      final OnActionMessageClickListener listener) {
    super(itemView, null);

    simpleText = (TextView) itemView.findViewById(R.id.chat_action_simple_text);

    actionButton.setOnClickListener(new View.OnClickListener() {
      @Override
      public void onClick(View v) {
        if (listener != null) {
          listener.actionMessageClicked(item);
        }
      }
    });
  }

  public void set(ActionMessageItem item) {
    super.set(item.getMessage(), false);
    setProfile(ChannelStore.getChannel());

    this.item = item;

    if (item.getActionType() == null) {
      actionFrame.setVisibility(View.GONE);
      actionButton.setVisibility(View.GONE);
    } else {
      switch (item.getActionType()) {
        case REQUEST_WORKING_TIME:
          actionFrame.setVisibility(View.VISIBLE);
          actionButton.setVisibility(View.VISIBLE);
          simpleText.setText(ResUtils.getString(itemView.getContext(), "ch.out_of_work.confirm"));
          break;
      }
    }
  }
}

==> dev-plugin-android-0.0.43-sources.jar: com/zoyi/channel/plugin/android/activity/chat/viewholder/ActionMessageHolder.java <==
package com.zoyi.channel.plugin.android.activity.chat.viewholder;

import android.text.Html;
import android.text.TextUtils;
import android.view.View;
import android.widget.TextView;

import com.zoyi.channel.plugin.android.ChannelStore;
import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.chat.listener.OnActionMessageClickListener;
import com.zoyi.channel.plugin.android.activity.chat.model.ActionMessageItem;
import com.zoyi.channel.plugin.android.util.ResUtils;

/**
 * Created by mika on 2017. 2. 1..
 */
public class ActionMessageHolder extends ManagerMessageHolder {
  private TextView simpleText;

  private ActionMessageItem item;

  public ActionMessageHolder(
      final View itemView,
      final OnActionMessageClickListener listener) {
    super(itemView, null);

    simpleText = (TextView) itemView.findViewById(R.id.chat_action_simple_text);

    actionButton.setOnClickListener(new View.OnClickListener() {
      @Override
      public void onClick(View v) {
        if (listener != null) {
          listener.actionMessageClicked(item);
        }
      }
    });
  }

  public void set(ActionMessageItem item) {
    super.set(item.getMessage(), false);

    if (!TextUtils.isEmpty(message.getMessage())) {
      text.setText(Html.fromHtml(message.getMessage()));
    }

    setProfile(ChannelStore.getChannel());

    this.item = item;

    if (item.getActionType() == null) {
      actionFrame.setVisibility(View.GONE);
      actionButton.setVisibility(View.GONE);
    } else {
      switch (item.getActionType()) {
        case REQUEST_WORKING_TIME:
          actionFrame.setVisibility(View.VISIBLE);
          actionButton.setVisibility(View.VISIBLE);
          simpleText.setText(ResUtils.getString(itemView.getContext(), "ch.out_of_work.confirm"));
          break;
      }
    }
  }
}
